@@ -1,4 +1,4 @@
-import { InvalidParameterError } from '@tamanu/shared/errors';
+import { InvalidParameterError } from '@tamanu/errors';
 
 import { hl7PatientFields, sortableHL7PatientFields } from '../hl7PatientFields';
 
